## INTRODUCTION

We provide a set of IDL wrappers for the ONERA/DESP FORTRAN library through the use of a shared library file (.dll on windows, .so on Unix). IDL access to any FORTRAN function with the use of the IDL function CALL_EXTERNAL (see IDL manual for more details).

## INSTALLATION

The ONERA/DESP compile scripts will create the shared library file for use with IDL (or Matlab) and is given a name "onera_desp_lib_OS.dll" or "onera_desp_lib_OS.so" depending on the platform, where OS can be either sunos_sparc, sunos_sparcV9, linux_x86, linux_x86_64, Win32_x86. The lib_name can be defined from IDL by the following:

case !version.os of
'linux':ext='so'
'sunos':ext='so'
'Win32':ext='dll'
endcase
lib_name=onera_desp_lib_+'_'+!version.os+'_'+!version.arch+'.'+ext

Thus, in order to access the library and the wrappers, the user needs only to use the CALL_EXTERNAL function where "image" (here refers as lib_name in the detailled function descriptions) provide the path+name of the shared library file.

## USE OF THE LIBRARY

When calling from IDL using call_external, ALL input and output variables have to be declared in the correct type. Failure to do this will result in a very ungracefull idl exit with no error messages or possibility of tracing! In general, integers need to be declared as longs and floats as double.